parade.tests package
====================

Submodules
----------

parade.tests.test\_cmdline module
---------------------------------

.. automodule:: parade.tests.test_cmdline
    :members:
    :undoc-members:
    :show-inheritance:


Module contents
---------------

.. automodule:: parade.tests
    :members:
    :undoc-members:
    :show-inheritance:
